<?php

namespace Drupal\wordfilter\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Wordfilter configuration entity.
 *
 * @ConfigEntityType(
 *   id = "wordfilter_configuration",
 *   label = @Translation("Wordfilter configuration"),
 *   admin_permission = "administer filters",
 *   handlers = {
 *     "list_builder" = "Drupal\wordfilter\WordfilterConfigurationListBuilder",
 *     "form" = {
 *       "add" = "Drupal\wordfilter\Form\WordfilterConfigurationForm",
 *       "edit" = "Drupal\wordfilter\Form\WordfilterConfigurationForm",
 *       "delete" = "Drupal\wordfilter\Form\WordfilterConfigurationDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\wordfilter\WordfilterConfigurationHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "wordfilter_configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "uuid",
 *     "substitute",
 *     "filter_words"
 *   },
 *   links = {
 *     "canonical" = "/admin/config/wordfilter_configuration/{wordfilter_configuration}",
 *     "add-form" = "/admin/config/wordfilter_configuration/add",
 *     "edit-form" = "/admin/config/wordfilter_configuration/{wordfilter_configuration}/edit",
 *     "delete-form" = "/admin/config/wordfilter_configuration/{wordfilter_configuration}/delete",
 *     "collection" = "/admin/config/wordfilter_configuration"
 *   }
 * )
 */
class WordfilterConfiguration extends ConfigEntityBase implements WordfilterConfigurationInterface {

  /**
   * The Wordfilter configuration ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The Wordfilter configuration label.
   *
   * @var string
   */
  protected $label;

  /**
   * The substitution string.
   *
   * @var string
   */
  protected $substitute = '';

  /**
   * The list of words to filter.
   * 
   * This list is being stored as a string,
   * words are being separated by ", ".
   *
   * @var string
   */
  protected $filter_words = '';

  /**
   * {@inheritdoc}
   */
  public function getFilterWords() {
    return $this->wordsToArray($this->filter_words);
  }
  
  /**
   * {@inheritdoc}
   */
   public function getSubstitute() {
     return $this->substitute;
   }
  
  /**
   * {@inheritdoc}
   */
  public function setFilterWords($words) {
    if (is_string($words)) {
      $words = $this->wordsToArray($words);
    }
    // Filter out duplicates.
    // Todo Replace with a case-insensitive filter.
    $words = array_unique($words);

    $words = implode(", ", $words);
    $this->filter_words = $words;
  }
  
  /**
   * {@inheritdoc}
   */
   public function setSubstitute($substitute) {
     $this->substitute = $substitute;
   }

  /**
   * Helper function to transorm a string of words to an array.
   *
   * @param $words_string
   *  The string of words, usually separated by ", ".
   * @return array
   *  The array of words.
   */
   protected function wordsToArray($words_string) {
     $words_array = explode(',', $words_string);
     $words_array = array_map('trim', $words_array);
     return $words_array;
   }
}
